pub struct DeviceFallbackError {
pub attempts: Vec<(Device, String)>,
}Expand description
Errors collected when every backend in the chain fails at run time.
Fields
attempts: Vec<(Device, String)>Trait Implementations
Sourceimpl Clone for DeviceFallbackError
impl Clone for DeviceFallbackError
Sourcefn clone(&self) -> DeviceFallbackError
fn clone(&self) -> DeviceFallbackError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceFallbackError
impl Debug for DeviceFallbackError
Sourceimpl Display for DeviceFallbackError
impl Display for DeviceFallbackError
impl Eq for DeviceFallbackError
Sourceimpl Error for DeviceFallbackError
impl Error for DeviceFallbackError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<String> for DeviceFallbackError
impl From<String> for DeviceFallbackError
Sourceimpl PartialEq for DeviceFallbackError
impl PartialEq for DeviceFallbackError
Sourcefn eq(&self, other: &DeviceFallbackError) -> bool
fn eq(&self, other: &DeviceFallbackError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceFallbackError