Multi-backend execution — compile once per device, run on any of them.
Structs
- Graph
Devices - A graph plus lazy per-device compiled executables.
Functions
- graph_
param_ names - Param names declared in
graph(Op::Param).
Multi-backend execution — compile once per device, run on any of them.
graph (Op::Param).