pub struct SamplerChain {
pub steps: Vec<Box<dyn Sampler>>,
}Expand description
A linear chain of samplers terminated by a softmax + multinomial
draw. Build one with SamplerChain::builder or directly from a Vec.
Fields
steps: Vec<Box<dyn Sampler>>Implementations
Sourceimpl SamplerChain
impl SamplerChain
pub fn new() -> Self
pub fn builder() -> SamplerChainBuilder
Sourcepub fn sample(
&self,
logits: Logits<'_>,
history: &[u32],
state: &mut SamplerState,
rng: &mut Philox4x32,
) -> u32
pub fn sample( &self, logits: Logits<'_>, history: &[u32], state: &mut SamplerState, rng: &mut Philox4x32, ) -> u32
Run every sampler in order over logits, then draw one token.