pub struct IoBindingEntry {
pub name: String,
pub node: NodeId,
pub dtype: DType,
pub shape: Shape,
pub elem_count: usize,
pub byte_size: usize,
pub arena_offset: Option<usize>,
pub arena_size: Option<usize>,
pub is_view: bool,
}Expand description
One named graph boundary with arena layout after buffer planning.
Fields
name: Stringnode: NodeIddtype: DTypeshape: Shapeelem_count: usizebyte_size: usizearena_offset: Option<usize>arena_size: Option<usize>is_view: boolTrait Implementations
Sourceimpl Clone for IoBindingEntry
impl Clone for IoBindingEntry
Sourcefn clone(&self) -> IoBindingEntry
fn clone(&self) -> IoBindingEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IoBindingEntry
impl Debug for IoBindingEntry
Sourceimpl PartialEq for IoBindingEntry
impl PartialEq for IoBindingEntry
Sourcefn eq(&self, other: &IoBindingEntry) -> bool
fn eq(&self, other: &IoBindingEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for IoBindingEntry
impl StructuralPartialEq for IoBindingEntry