pub struct RuntimeOverrides { /* private fields */ }Expand description
RAII guard: installs overrides on construction, restores previous values on drop.
Implementations
Sourceimpl RuntimeOverrides
impl RuntimeOverrides
Sourcepub fn install(
pairs: impl IntoIterator<Item = (impl AsRef<str>, impl Into<String>)>,
) -> RuntimeOverrides
pub fn install( pairs: impl IntoIterator<Item = (impl AsRef<str>, impl Into<String>)>, ) -> RuntimeOverrides
Install pairs for the lifetime of the returned guard.