slice_rows

Function slice_rows 

pub fn slice_rows(data: &[f32], inner: usize, actual: usize) -> Vec<f32>
Slice data (interpreted as [upper, inner] row-major) down to actual rows. Companion of pad_rows.

Panics if data.len() is not a multiple of inner, if inner == 0, or if actual exceeds the number of rows in data.