Static IO / sync profile for compiled graphs (Phase 0 — fusion planning).
Structs
- Graph
IoOptions - Tuning for static IO analysis.
- Graph
IoProfile - Host-visible traffic and sync points for one forward pass.
Functions
- metal_
host_ sync_ kinds - Ops that force a GPU sync + host thunk on Metal today.
- profile_
graph_ io - Profile a graph before compile (conservative static estimate).
- profile_
graph_ io_ outputs - Profile with only selected outputs materialized on the host (peaks-only, logits-only, …).
- profile_
graph_ io_ with_ options