pub struct LmRunnerBuilder<Cfg> {
pub weights: Option<PathBuf>,
pub config: ConfigSource<Cfg>,
pub device: Device,
pub max_seq: usize,
pub max_memory_gb: Option<f32>,
pub stream: bool,
pub sample: SampleOpts,
pub format: Option<WeightFormat>,
pub packed_weights: Option<bool>,
pub prefer_gguf: Option<String>,
}Expand description
Builder fields common to every per-family runner.
Per-family runner builders should wrap this and forward the
methods (or use #[rlx_runner] from rlx-macros).
Fields
weights: Option<PathBuf>config: ConfigSource<Cfg>device: Devicemax_seq: usizemax_memory_gb: Option<f32>stream: boolsample: SampleOptsformat: Option<WeightFormat>packed_weights: Option<bool>None = auto-detect (packed when GGUF ≥ 256 MB).
prefer_gguf: Option<String>Substring for picking one GGUF in a directory (default Q4_K_M).
Implementations
Sourceimpl<Cfg> LmRunnerBuilder<Cfg>
impl<Cfg> LmRunnerBuilder<Cfg>
pub fn new() -> Self
pub fn weights<P: Into<PathBuf>>(self, p: P) -> Self
pub fn config(self, src: ConfigSource<Cfg>) -> Self
pub fn config_value(self, cfg: Cfg) -> Self
pub fn device(self, d: Device) -> Self
pub fn max_seq(self, n: usize) -> Self
pub fn max_memory_gb(self, gb: f32) -> Self
pub fn stream(self, on: bool) -> Self
pub fn sample(self, s: SampleOpts) -> Self
pub fn format(self, fmt: WeightFormat) -> Self
pub fn packed_weights(self, on: bool) -> Self
pub fn prefer_gguf<S: Into<String>>(self, q: S) -> Self
Sourcepub fn resolved_format(&self) -> Result<WeightFormat>
pub fn resolved_format(&self) -> Result<WeightFormat>
Resolve the format using the explicit override or the file extension.
Sourcepub fn resolved_packed(&self, fmt: WeightFormat) -> bool
pub fn resolved_packed(&self, fmt: WeightFormat) -> bool
Determine whether packed GGUF loading should be used. Honors an
explicit override; otherwise auto-enables for GGUF files at or
above PACKED_GGUF_AUTO_THRESHOLD_BYTES.